@@ -1,8 +1,6 @@
 !=======================================================================
 !
-!  PROGRAM  PHASE/0 2014.01 (rev.375)
-!
-!  "First-principles Electronic Structure Calculation Program"
+!  PROGRAM  PHASE/0 2014.02 ($Rev: 389 $)
 !
 !  SUBROUINE:  readop, altv_2_rltv, string2values, inver3n,
 !              matpr3, inver2n, gnrt_op, gnrt_op_n,
@@ -19,22 +17,25 @@
 !
 !=======================================================================
 !
-!   The original version of this set of the computer programs "PHASE" was developed by 
-!  the members of the Theory Group of Joint Research Center for Atom Technology 
-!  (JRCAT), based in Tsukuba, in the period 1993-2001.  
-!   Since 2002, this program set had been intensively developed as a part of the following 
-!  national projects supported by the Ministry of Education, Culture, Sports, Science and 
-!  Technology (MEXT) of Japan; "Frontier Simulation Software for Industrial Science 
-!  (FSIS)" from 2002 to 2005, "Revolutionary Simulation Software (RSS21)" from 2006 to 
-!  2008. "Research and Development of Innovative Simulation Software (RISS)" from 2008 
-!  to 2013. These projects is lead by the Center for Research on Innovative Simulation 
-!  Software (CISS), the Institute of Industrial Science (IIS), the University of Tokyo.
-!   Since 2013, this program set has been further developed centering on PHASE System 
-!  Consortium. 
+!     The original version of this set of the computer programs "PHASE"
+!  was developed by the members of the Theory Group of Joint Research
+!  Center for Atom Technology (JRCAT), based in Tsukuba, in the period
+!  1993-2001.
+!
+!     Since 2002, this set has been tuned and new functions have been
+!  added to it as a part of the national project "Frontier Simulation 
+!  Software for Industrial Science (FSIS)",  which is supported by
+!  the IT program of the Ministry of Education, Culture, Sports,
+!  Science and Technology (MEXT) of Japan. 
+!     Since 2006, this program set has been developed as a part of the
+!  national project "Revolutionary Simulation Software (RSS21)", which
+!  is supported by the next-generation IT program of MEXT of Japan.
+!   Since 2013, this program set has been further developed centering on PHASE System
+!  Consortium.
 !   The activity of development of this program set has been supervised by Takahisa Ohno.
 !
 subroutine readop(ipri,kopr,altv,nfout,nfopgr,nfmatbp,Iparas,nopr,op,tau,af)
-! $Id: b_Crystal_Structure.f90 238 2012-11-12 04:11:13Z yamasaki $
+! $Id: b_Crystal_Structure.f90 389 2014-07-01 10:06:54Z jkoga $
 !
 !      read operation matrix OP(3,3,kopr) and TAU(3,kopr)
 !      from the file 'opgr.data'
@@ -924,13 +925,13 @@ subroutine bravais2primitive(nfout,b2pmat,a,b,c,ca,cb,cc,avec,bvec,cvec,il)
   end do
 
   if (il == -1) then                  ! Trigonal
-     if (abs(ca)>epsilon .or. abs(cb)>epsilon .or. abs(cc+0.5d0)>epsilon) then
+     if (abs(ca)>epsilon .or. abs(cb)>epsilon .or. abs(abs(cc)-0.5d0)>epsilon) then
 !!$        write(nfout,'(" You must have given wrong lattice.: ca, cb, cc = ",3f8.4," (il=-1)")') ca, cb, cc
         write(nfout,1001) ca,cb,cc,il
         stop ' il = -1 <<bravais2primitive>>'
      end if
   else if (il == 0) then ! Primitive (Hexagonal)
-     if (abs(ca)>epsilon .or. abs(cb)>epsilon .or. abs(cc+0.5d0)>epsilon) then
+     if (abs(ca)>epsilon .or. abs(cb)>epsilon .or. abs(abs(cc)-0.5d0)>epsilon) then
 !!$        write(nfout,'(" You must have given wrong lattice.: ca, cb, cc = ",3f8.4,', ca, cb, cc
         write(nfout,1001) ca,cb,cc,il
         stop ' il = 0  <<bravais2primitive>>'
@@ -1027,3 +1028,13 @@ subroutine primitive2bravais(nfout,p2bmat,avec,bvec,cvec,a,b,c,ca,cb,cc,il)
   end if
 
 end subroutine primitive2bravais
+
+logical function is_hexagonal(ca,cb,cc)
+  use m_Const_Parameters, only : DP
+  implicit none
+  real(kind=DP), intent(in) :: ca,cb,cc
+  real(kind=DP), parameter     :: epsilon = 1.d-10
+  is_hexagonal = .false.
+  if (abs(ca)<epsilon .and. abs(cb)<epsilon .and. abs(abs(cc)-0.5d0)<epsilon) is_hexagonal=.true.
+
+end function is_hexagonal
